<p align="center">
    <br>
    <img src="https://user-images.githubusercontent.com/66180831/209478341-a1b4d80b-dbcb-448c-a3e0-109e27590ec5.png" width="400"/>
    <br>
<p>

# XAISuite: Training and Explaining Machine Learning Models
<div align="center">
  <a href="#">
  <img src="https://img.shields.io/badge/Python-3.7, 3.8, 3.9, 3.10-blue">
  </a>
  
  <a href="https://pypi.python.org/pypi/XAISuite">
  <img alt="PyPI" src="https://img.shields.io/pypi/v/XAISuite"/>
  </a>
  
  <a href="https://pepy.tech/project/XAISuite">
  <img alt="Downloads" src="https://img.shields.io/github/downloads/11301858/XAISuite/total">
  </a>
  
  <!-- Some more badges to display, upon release
  <a href="https://opensource.salesforce.com/OmniXAI">
  <img alt="Documentation" src="https://github.com/salesforce/OmniXAI/actions/workflows/docs.yml/badge.svg"/>
  </a>
  
  <a href="https://arxiv.org/abs/2206.01612">
  <img alt="DOI" src="https://zenodo.org/badge/DOI/10.48550/ARXIV.2206.01612.svg"/>
  </a>
  -->
</div>

## Table of Contents
1. [Introduction](#introduction)
2. [Installation](#installation)
3. [Getting Started](#getting-started)
4. [How to Contribute]()
5. [Technical Report and Citing XAISuite]()


## Introduction

XAISuite (E<u><b>x</b></u>planatory <u><b>A</b></u>rtificial <u><b>I</b></u>ntelligence <u><b>Suite</b></u> is a library for training and explaining machine learning models for tabular datasets in Python. It provides a unified interface for training any model using just a line of code and easily comparing the results of different explainers!





## Installation
You can install ``XAI Suite`` through PyPI:

``
pip install XAISuite
``

## Getting Started

For example code and an introduction to the library, see the Demo Folder.


## How to Contribute

We welcome the contribution from the open-source community to improve the library!

To add a new explanation method/feature into the library, please follow the template and steps demonstrated in this 
[documentation]().

## Technical Report and Citing XAISuite
A research paper has not been published yet. Until then, cite "Shreyan Mitra - XAISuite (paper pending)"



## Contact Us
If you have any questions, comments or suggestions, please do not hesitate to contact us at shreyan.m.mitra@gmail.com

## License

[BSD 3-Clause License](LICENSE)
